#!/bin/bash

# Make sure there are arguments provided
if [ "$#" -ne 1 ]; then
    echo "Usage: $0 filename.srt"
    exit 1
fi

# File name .srt
srt_file="$1" #SRT file
temp_file="temp-text.txt" # Temporary file
output_file="result_dialog.txt" # Result file

# Check if the file exists
if [ ! -f "$srt_file" ]; then
    echo "File not found!"
    exit 1
fi

# Read files and extract dialog text
line_number=0
while IFS= read -r line; do
    line_number=$((line_number + 1))
    # Check if the row is dialog text (not a number or timestamp)
    if [[ ! "$line" =~ ^[0-9]+$ ]] && [[ "$line" != *"-->"* ]] && [[ -n "$line" ]]; then
        echo "$line_number = $line" >> temp-text.txt
    fi
done < "$srt_file"

# Delete the contents of the output file if it already exists
> "$output_file"

{
    while IFS= read -r line; do
	# Check if the line contains non-empty dialog text
        if [[ "$line" =~ ^[0-9]+\ =\ [^0-9[:space:]] ]]; then
            echo "$line" >> "$output_file"
        fi
    done < "$temp_file"
}

# Remove temporary file
rm $temp_file
